@@ -8,11 +8,10 @@ Created on Tue Jan 27 23:13:42 2015, 2020
 from __future__ import absolute_import, division, print_function, unicode_literals
 
 from .simplesbml import SbmlModel
+from .simplesbml import loadSBMLStr
+from .simplesbml import loadSBMLFile
 
-__version__ = '1.3.3'
-
-
-
+__version__ = '2.0.3'
 
 
 
